#!/bin/sh

# shellcheck disable=SC3040
set -eu -o pipefail

readonly REPOS="backports ilot"
readonly BASEBRANCH=$GITHUB_BASE_REF
readonly TARGET_REPO=$CI_ALPINE_REPO

apkgs=$(find package -type f -name "*.apk")

for apk in $apkgs; do
	branch=$(echo $apk | awk -F '/' '{print $2}')
	arch=$(echo $apk | awk -F '/' '{print $3}')
	name=$(echo $apk | awk -F '/' '{print $4}')

	if [ "$(curl -s $GITHUB_SERVER_URL/api/v1/repos/$GITHUB_REPOSITORY/pulls/$GITHUB_EVENT_NUMBER | jq .draft)" == "true" ]; then
		# if draft, send to -testing branch
		branch="$branch-testing"
	fi

	# always clear out package before deploying
	for delarch in x86_64 aarch64 armv7 armhf s390x ppc64le riscv64 loongarch64 x86; do
		curl -s --user $FORGE_REPO_USER:$FORGE_REPO_TOKEN -X DELETE $TARGET_REPO/$BASEBRANCH/$branch/$delarch/$name 2>&1 > /dev/null
	done

	echo "Sending $name of arch $arch to $TARGET_REPO/$BASEBRANCH/$branch"
	curl -s --user $FORGE_REPO_USER:$FORGE_REPO_TOKEN --upload-file $apk $TARGET_REPO/$BASEBRANCH/$branch

done

